Library for RS485 Modbus Chirp soil moisture sensor
===================================================

A wrapper library for communication with `RS485 Modbus Soil Moisture Sensor
<https://github.com/Miceuz/rs485-moist-sensor/>` by Albertas Mickėnas (mic@wemakethings.net).

